## [Unreleased]

## [0.2.7] - 2019-08-20
### Added
- Compatibility Django 2.2

## [0.2.6] - 2018-06-31
### Added
- Support Django 2.0

### Removed
- Support Django 1.7

## [0.2.5] - 2016-04-07
### Added
- Add support Django 1.11

## [0.2.4] - 2016-07-29
### Added
- Add support Django 1.10

## [0.2.3] - 2016-01-04
### Added
- Add support Django 1.9

[Unreleased]: https://github.com/silentsokolov/django-automatic-links/compare/v0.2.7...HEAD
[0.2.7]: https://github.com/silentsokolov/django-automatic-links/compare/v0.2.6...v0.2.7
[0.2.6]: https://github.com/silentsokolov/django-automatic-links/compare/v0.2.5...v0.2.6
[0.2.5]: https://github.com/silentsokolov/django-automatic-links/compare/v0.2.4...v0.2.5
[0.2.4]: https://github.com/silentsokolov/django-automatic-links/compare/0.2.3...v0.2.4
